from fastapi import APIRouter
from loguru import logger

from app.controllers.algorithms.graph_coloring import get_graph_coloring
from app.models.domain.algorithms import GraphColoringRequest, GraphColoringResponse
from app.models.domain.algorithms import AttendeesRecommendationRequest, AttendeesRecommendationResponse

router = APIRouter()


@router.get('/status')
async def get_living_condition():
    return {'message': 'alive'}


@router.post('/graph-coloring', response_model=GraphColoringResponse)
async def get_graph_coloring_result(graph: GraphColoringRequest):
    is_solvable, colored = await get_graph_coloring(graph.graph)

    solution = {
        'is_solvable': is_solvable,
        'colored': colored
    }

    return solution


@router.post('/attendees-recommendation', response_model=AttendeesRecommendationResponse)
async def get_recommended(meeting_info: AttendeesRecommendationRequest):
    return {
        'code': 200,
        'message': 'Test',
        'data': {
            'userIdList': []
        }
    }
